==> MuSE-0.6.3.tar.gz: MuSE-0.6.3/inchannels.h <==
/* inchannels.h - MuSE
   (c)2000 Denis Roio aka jaromil
   see COPYING for licensing stuff

   different classes for different IN channels
   they are instantiated and used by the Stream_mixer class (jmixer.cpp)
*/

#ifndef __INCHANNELS_H
#define __INCHANNELS_H

#define MP3CHAN 1
#define OGGCHAN 2

#include <stdio.h>
#include <pthread.h>
#include <config.h>

/* muse generic tweakin headers */
#include "generic.h"

/* mixing and audioprocessing algorithms*/
#include "audioproc.h"

#include "jutils.h"

#ifdef HAVE_VORBIS
/* oggvorbis lib */
extern "C" {
#include <ogg/ogg.h>
#include <vorbis/codec.h>
#include <vorbis/vorbisfile.h>
}
#endif

/* mpeg lib (splay) */
#include "libmpeg/mpegsound.h"


struct timecode {
  int h;
  int m;
  int s;
  float f;
};

typedef int (Mixer )(int*, short*, int, float);

/* parent class Channel
   this class shadows codec specific classes to the jmixer
   never instantiated: it's being inherited from decoders
*/

class Channel {
 private:
  virtual float _get_audio() = 0;

  /* pthread stuff */
  void _thread_init();
  void _thread_destroy();
  bool _thread_initialized;
  
  pthread_t _thread;
  pthread_attr_t _attr;

  pthread_mutex_t _mutex;
  pthread_cond_t _cond;
  /* ------------- */

 public:
  Channel() { _thread_initialized = false; };
  virtual ~Channel() { };

  /* pthread stuff */
  void start();
  void run();
  void lock() { pthread_mutex_lock(&_mutex); };
  void unlock() { pthread_mutex_unlock(&_mutex); };
  void wait() { pthread_cond_wait(&_cond,&_mutex); };
  void signal() { pthread_cond_signal(&_cond); };
  void destroy() { _thread_destroy(); };
  /* ------------- */

  virtual int set(char *file) = 0;
  virtual bool play() = 0;
  virtual bool stop() = 0;
  virtual bool pos(float pos) = 0;
  virtual void clean() { };
  float mix(int *mixpcm);

  float upd_time();
  bool set_mixer();

  unsigned char *buffo;
  float _res;
  Mixer *mixxx;  

  float volume;
  float position;
  int speed;
  struct timecode time;

  int samplerate;
  int channels;
  int bitrate;
  
  enum { LOOP, CONT, PLAY } playmode;

  bool opened;
  bool on;
  bool update;
  bool seekable;
  bool running;

  int in_smp;
  int frametot, framepos, fps;  

  int type;

 protected:
  static void* kickoff(void *arg) { ((Channel *) arg)->run(); return NULL; };

};

#ifdef HAVE_VORBIS

/* OggVorbis Channel // ogg-vorbis decoding */

class OggChannel: public Channel {
 private:
  OggVorbis_File   vf;
  vorbis_info      *vi;
  vorbis_comment   *vc;

  int current_section, old_section;

  FILE *oggfile;
  float _get_audio();
  char _buffone[32768];

 public:
  OggChannel();
  ~OggChannel();

  void run() { Channel::run(); };
  int set(char *file);
  bool play();
  bool stop();
  bool pos(float pos);
  void clean();
};

#endif

/* Mpeg Channel // MPEG-1 layer 1,2,3 and MPEG-2 layer 3 */

class MpegChannel: public Channel {
 private:
  Soundinputstream *loader;
  Mpegtoraw *server;
  float _get_audio();
  int framesize;
  
 public:
  MpegChannel();
  ~MpegChannel();
  
  void run() { Channel::run(); };
  int set(char *file);
  bool play();
  bool stop();
  bool pos(float pos);
  void clean();

};

/* dsp-in Channel // get sound from soundcard's dsp */
  
class LiveIn {
 private:
  int *dsp;
  unsigned int num_samples;
  int sample_rate;
  int opt;

  int get_audio();  

 public:
  LiveIn(int smpr, int chans, int *thedsp);
  ~LiveIn();
  
  int mix(int *mixpcm);

  short *gotin;
  int channels;
  int rate;
  bool on;
};

#endif

==> MuSE-0.6.4.tar.gz: MuSE-0.6.4/inchannels.h <==
/* MuSE - Multiple Streaming Engine
 * Copyright (C) 2000-2002 Denis Roio aka jaromil <jaromil@dyne.org>
 *
 * This source code is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Public License as published 
 * by the Free Software Foundation; either version 2 of the License,
 * or (at your option) any later version.
 *
 * This source code is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * Please refer to the GNU Public License for more details.
 *
 * You should have received a copy of the GNU Public License along with
 * this source code; if not, write to:
 * Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *
 * different classes for different IN channels
 * they are instantiated and used by the Stream_mixer class (jmixer.cpp)
 */

#ifndef __INCHANNELS_H
#define __INCHANNELS_H

#define MP3CHAN 1
#define OGGCHAN 2

#include <stdio.h>
#include <pthread.h>
#include <config.h>

/* muse generic tweakin headers */
#include "generic.h"

/* mixing and audioprocessing algorithms*/
#include "audioproc.h"

#include "jutils.h"

#ifdef HAVE_VORBIS
/* oggvorbis lib */
extern "C" {
#include <ogg/ogg.h>
#include <vorbis/codec.h>
#include <vorbis/vorbisfile.h>
}
#endif

/* mpeg lib (splay) */
#include "libmpeg/mpegsound.h"

struct timecode {
  int h;
  int m;
  int s;
  float f;
};

typedef int (Mixer )(int*, short*, int, float);

/* parent class Channel
   this class shadows codec specific classes to the jmixer
   never instantiated: it's being inherited from decoders
*/

class Channel {
 private:
  virtual float _get_audio() = 0;

  /* pthread stuff */
  void _thread_init();
  void _thread_destroy();
  bool _thread_initialized;
  
  pthread_t _thread;
  pthread_attr_t _attr;

  pthread_mutex_t _mutex;
  pthread_cond_t _cond;
  /* ------------- */

 public:
  Channel();
  ~Channel() { func("Channel::~Channel()"); destroy(); };

  /* pthread stuff */
  void start() {
    _thread_init();
    pthread_create(&_thread, &_attr, &kickoff, this); };
  void run();
  void lock() { pthread_mutex_lock(&_mutex); };
  void unlock() { pthread_mutex_unlock(&_mutex); };
  void wait() { pthread_cond_wait(&_cond,&_mutex); };
  void signal() { pthread_cond_signal(&_cond); };
  void destroy() { _thread_destroy(); };
  /* ------------- */

  virtual int set(char *file) = 0;
  virtual bool play() = 0;
  virtual bool stop() = 0;
  virtual bool pos(float pos) = 0;
  virtual void clean() = 0;
  float mix(int *mixpcm);

  float upd_time();
  bool set_mixer();

  unsigned char *buffo;
  float _res;
  Mixer *mixxx;  

  float volume;
  float position;
  int speed;
  struct timecode time;

  int samplerate;
  int channels;
  int bitrate;
  
  enum { LOOP, CONT, PLAY } playmode;

  bool opened;
  bool on;
  bool update;
  bool seekable;
  bool running;
  bool rewinding;

  int in_smp;
  int frametot, framepos, fps;  

  int type;

 protected:
  static void* kickoff(void *arg) { ((Channel *) arg)->run(); return NULL; };

};

#ifdef HAVE_VORBIS

/* OggVorbis Channel // ogg-vorbis decoding */

class OggChannel: public Channel {
 private:
  OggVorbis_File   vf;
  vorbis_info      *vi;
  vorbis_comment   *vc;

  int current_section, old_section;

  FILE *oggfile;
  float _get_audio();
  char _buffone[32768];

 public:
  OggChannel();
  ~OggChannel();

  int set(char *file);
  bool play();
  bool stop();
  bool pos(float pos);
  void clean();
};

#endif

/* Mpeg Channel // MPEG-1 layer 1,2,3 and MPEG-2 layer 3 */

class MpegChannel: public Channel {
 private:
  Soundinputstream *loader;
  Mpegtoraw *server;
  float _get_audio();
  int framesize;
  
 public:
  MpegChannel();
  ~MpegChannel();
  
  int set(char *file);
  bool play();
  bool stop();
  bool pos(float pos);
  void clean();

};

/* dsp-in Channel // get sound from soundcard's dsp */
  
class LiveIn {
 private:
  int *dsp;
  unsigned int num_samples;
  int sample_rate;
  int opt;

  int get_audio();  

 public:
  LiveIn(int smpr, int chans, int *thedsp);
  ~LiveIn();
  
  int mix(int *mixpcm);

  short *gotin;
  int channels;
  int rate;
  bool on;
};

#endif
